"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OptionsSkin = void 0;

var _isObject2 = _interopRequireDefault(require("lodash/isObject"));

var _isFunction2 = _interopRequireDefault(require("lodash/isFunction"));

var _react = _interopRequireDefault(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Bubble = require("../../components/Bubble");

var _ScrollBar = require("../../components/ScrollBar");

var _BubbleSkin = require("./BubbleSkin");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

// external libraries
// components
// skins
var OptionsSkin = function OptionsSkin(props) {
  var getOptionProps = props.getOptionProps,
      getHighlightedOptionIndex = props.getHighlightedOptionIndex,
      handleClickOnOption = props.handleClickOnOption,
      isHighlightedOption = props.isHighlightedOption,
      isOpen = props.isOpen,
      isOpeningUpward = props.isOpeningUpward,
      isSelectedOption = props.isSelectedOption,
      noOptionsArrow = props.noOptionsArrow,
      noResults = props.noResults,
      noResultsMessage = props.noResultsMessage,
      noSelectedOptionCheckmark = props.noSelectedOptionCheckmark,
      optionHeight = props.optionHeight,
      optionsMaxHeight = props.optionsMaxHeight,
      optionRenderer = props.optionRenderer,
      options = props.options,
      optionsRef = props.optionsRef,
      render = props.render,
      setHighlightedOptionIndex = props.setHighlightedOptionIndex,
      setMouseIsOverOptions = props.setMouseIsOverOptions,
      targetRef = props.targetRef,
      theme = props.theme,
      themeId = props.themeId;
  var highlightedOptionIndex = getHighlightedOptionIndex();
  var isFirstOptionHighlighted = highlightedOptionIndex === 0;
  var sortedOptions = isOpeningUpward ? options.slice().reverse() : options;

  var renderOptions = function renderOptions() {
    // check for user's custom render function
    // if Options is being rendered via Autocomplete,
    // the value of props.render is renderOptions passed down from AutocompleteSkin
    if (!noResults && render) {
      // call user's custom render function
      return render(getOptionProps);
    } else if (!noResults && !render) {
      // render default simple skin
      return sortedOptions.map(function (option, index) {
        // set reference of event handlers in memory to prevent excess re-renders
        var boundSetHighlightedOptionIndex = setHighlightedOptionIndex.bind(null, index);
        var boundHandleClickOnOption = handleClickOnOption.bind(null, option);
        return (
          /*#__PURE__*/
          _react["default"].createElement("li", {
            role: "presentation",
            "aria-hidden": true,
            key: index,
            className: (0, _classnames["default"])([option.className ? option.className : null, theme[themeId].option, isHighlightedOption(index) ? theme[themeId].highlightedOption : null, isSelectedOption(index) ? theme[themeId].selectedOption : null, option.isDisabled ? theme[themeId].disabledOption : null, noSelectedOptionCheckmark ? theme[themeId].hasNoSelectedOptionCheckmark : null]),
            onClick: boundHandleClickOnOption,
            onMouseEnter: boundSetHighlightedOptionIndex
          }, renderOption(option))
        );
      });
    } // render no results message


    return (
      /*#__PURE__*/
      _react["default"].createElement("li", {
        className: theme[themeId].option
      }, noResultsMessage)
    );
  };

  var renderOption = function renderOption(option) {
    // check if user has passed render prop "optionRenderer"
    if (optionRenderer && (0, _isFunction2["default"])(optionRenderer)) {
      // call user's custom rendering logic
      return optionRenderer(option);
    } else if ((0, _isObject2["default"])(option)) {
      return (
        /*#__PURE__*/
        _react["default"].createElement("span", {
          className: theme[themeId].label
        }, option.label)
      );
    }

    return option;
  };

  var getScrollBarHeight = function getScrollBarHeight() {
    if (!options.length) return optionHeight;

    if (optionsMaxHeight < options.length * optionHeight) {
      return optionsMaxHeight;
    }

    return options.length * optionHeight;
  }; // Enforce max height of options dropdown if necessary


  var optionsStyle = optionsMaxHeight == null ? null : {
    maxHeight: "".concat(optionsMaxHeight, "px")
  };
  return (
    /*#__PURE__*/
    _react["default"].createElement(_Bubble.Bubble, {
      className: (0, _classnames["default"])([theme[themeId].options, isOpen ? theme[themeId].isOpen : null, isOpeningUpward ? theme[themeId].openUpward : null, isFirstOptionHighlighted && !noResults ? theme[themeId].firstOptionHighlighted : null]),
      isTransparent: false,
      skin: _BubbleSkin.BubbleSkin,
      isOpeningUpward: isOpeningUpward,
      isHidden: !isOpen,
      isFloating: true,
      noArrow: noOptionsArrow,
      targetRef: targetRef
    },
    /*#__PURE__*/
    _react["default"].createElement("ul", {
      style: optionsStyle,
      ref: optionsRef,
      className: theme[themeId].ul,
      onMouseEnter: function onMouseEnter() {
        return setMouseIsOverOptions && setMouseIsOverOptions(true);
      },
      onMouseLeave: function onMouseLeave() {
        return setMouseIsOverOptions && setMouseIsOverOptions(false);
      }
    },
    /*#__PURE__*/
    _react["default"].createElement(_ScrollBar.ScrollBar, {
      style: {
        height: "".concat(getScrollBarHeight(), "px")
      }
    }, renderOptions())))
  );
};

exports.OptionsSkin = OptionsSkin;
//# sourceMappingURL=OptionsSkin.js.map